.. MetaWear C++ API documentation master file, created by
   sphinx-quickstart on Sat Apr  9 14:01:21 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Introduction
============
The MetaWear C++ API provides a low level implementation of the `MetaWear <https://mbientlab.com/metawear/>`_ Bluetooth LE protocol that can be used in 
C/C++ projects or by higher level languages such as Javascript and Python; it **does not** provide any Bluetooth LE functionality.  Source code for 
the API is available on the `Metawear-SDK-Cpp <https://github.com/mbientlab/Metawear-SDK-Cpp>`_ project page which also include Javascript and Python 
bindings.

.. toctree::
    :hidden:
    :maxdepth: 1

    btlecommunication
    mblmwmetawearboard
    mblmwevent
    mblmwdatasignal
    mblmwdataprocessor
    mblmwlogger
    core_modules
    sensors
    peripherals
    advanced_features
